@@ -6,7 +6,7 @@ use base qw/Catalyst::View/;
 
 use Data::Dumper;
 
-our $VERSION = '2.1';
+our $VERSION = '2.2';
 
 
 =head1 NAME
@@ -25,7 +25,8 @@ Catalyst::View::Seamstress - HTML::Seamstress View Class for Catalyst
 # in lib/MyApp/View/Seamstress.pm
 
 # create your seamstress template packaged with spkg.pl
-# see HTML::Seamstress
+# see HTML::Seamstress.. This will give you a .pm file to go with your html, 
+# so something like html::helloworld
 
 # render view from lib/MyApp.pm or lib/MyApp::C::SomeController.pm
 
@@ -42,10 +43,23 @@ Catalyst::View::Seamstress - HTML::Seamstress View Class for Catalyst
         $c->forward('MyApp::View::Seamstress');
     }
 
+# and in your html::helloworld you can do something like:
+
+ sub process{
+     my( $tree, $c, $stash ) = @_;
+     
+     $tree->look_down( id => 'name' )->replace_content( $stash->{name} );
+ }
+
 
 =head1 DESCRIPTION
 
-This is the Catalyst view class for L<HTML::Seamstress|HTML::Seamstress>.
+
+This is the Catalyst view class for L<HTML::Seamstress|HTML::Seamstress>. It allows 
+templating with proper seperation between code and HTML. This means you can get a 
+designer/friend/client/stooge to make your templates for you without having to 
+teach them a mini-language!
+
 Your application should define a view class which is a subclass of
 this module.  The easiest way to achieve this is using the
 F<myapp_create.pl> script (where F<myapp> should be replaced with
@@ -74,7 +88,7 @@ to the Seamstress view class.
 Or you might like to use 
 L<Catalyst::Plugin::DefaultEnd|Catalyst::Plugin::DefaultEnd>
 
-or even
+..or even
 L<Catalyst::Action::RenderView|Catalyst::Action::RenderView>
 
 
@@ -235,6 +249,8 @@ sub page2tree {
 sub process {
     my ( $self, $c ) = @_;
 
+    my $body_is_skeleton = 0;
+
     my ($skeleton, $meat, $body) ;
 
     my $loom = $c->stash->{LOOM};
@@ -271,9 +287,7 @@ sub process {
           $self, $c, $c->stash, $meat, $skeleton
        );
 
-      # $body = $self->page2tree($c, $skeleton, 'fixup');
-      # this should be additional controller actions for the request
-
+      $body_is_skeleton = 1;
       $body = $skeleton ;
     }
 
@@ -296,9 +310,9 @@ sub process {
     $c->response->body( $response_body );
 
 
-    # If loom is a class-name we're not doing anything especially fancy, so
-    # we'll just delete it:
-    unless ( ref $loom ) {
+    # we delete the body unless our loom ( or skeleton if we have one) is a reference
+    # which we take as a sign that the user is doing something more elaborate caching or something..
+    unless( (! $body_is_skeleton && ref $loom)  ||  ( $body_is_skeleton && ref $self->config->{skeleton} ) ) {
         $body->delete;
     }
 
